@@ -9,6 +9,7 @@ const translationMap = {
                 de: 'Script Pfad',
                 pt_br: 'Localização do Script',
                 sp: 'Localización del Script',
+                sp_la: 'Ubicacion del archivo',
                 tr: 'Script Konumu',
                 th: 'ตำแหน่งสคริปต์',
                 fr: 'Emplacement des scripts',
@@ -18,6 +19,24 @@ const translationMap = {
                 gr: 'Διαδρομή Αρχείου',
                 ar: 'موقع البرنامج النصي',
             },
+            language: {
+                en: 'Language',
+                zh: '成语',
+                zh_tw: '成語',
+                ru: 'идиома',
+                de: 'Idiom',
+                pt_br: 'Idioma',
+                sp: 'Idioma',
+                sp_la: 'Idioma',
+                tr: 'Deyim',
+                th: 'สำนวน',
+                fr: 'Langage',
+                it: 'Idioma',
+                id: 'Idiom',
+                cz: 'Idiom',
+                gr: 'ιδίωμα',
+                ar: 'لغة. مثل',
+            },
             oneFile: {
                 en: 'Onefile',
                 zh: '单文件',
@@ -26,6 +45,7 @@ const translationMap = {
                 de: 'Eine Datei',
                 pt_br: 'Arquivo Único',
                 sp: 'Archivo Único',
+                sp_la: 'Tipo de archivo',
                 tr: 'Tek Dosya',
                 th: 'หนึ่งไฟล์',
                 fr: 'un fichier',
@@ -43,6 +63,7 @@ const translationMap = {
                 de: 'Konsolen Anwendung',
                 pt_br: 'Janela do Console',
                 sp: 'Consola de Windows',
+                sp_la: 'Tipo de consola',
                 tr: 'Konsol Penceresi',
                 th: 'หน้าต่างคอนโซล',
                 fr: 'Console Windows',
@@ -60,6 +81,7 @@ const translationMap = {
                 de: 'Icon',
                 pt_br: 'Ícone',
                 sp: 'Icono',
+                sp_la: 'Ícono',
                 tr: 'Simge',
                 th: 'ไอคอน',
                 fr: 'Icone',
@@ -77,6 +99,7 @@ const translationMap = {
                 de: 'Dateien hinzufügen',
                 pt_br: 'Arquivos Adicionais',
                 sp: 'Archivos adicionales',
+                sp_la: 'Archivos adicionales',
                 tr: 'Ek dosyalar',
                 th: 'ไฟล์เพิ่มเติม',
                 fr: 'Fichiers additionnels',
@@ -94,6 +117,7 @@ const translationMap = {
                 de: 'Erweitert',
                 pt_br: 'Avançado',
                 sp: 'Avanzado',
+                sp_la: 'Avanzado',
                 tr: 'Daha Fazla',
                 th: 'ขั้นสูง',
                 fr: 'Paramètres avancées',
@@ -111,6 +135,7 @@ const translationMap = {
                 de: 'Einstellungen',
                 pt_br: 'Configurações',
                 sp: 'Configuraciones',
+                sp_la: 'Configuración',
                 tr: 'Ayarlar',
                 th: 'การตั้งค่า',
                 fr: 'Paramètres',
@@ -128,6 +153,7 @@ const translationMap = {
                 de: 'Aktueller Befehl',
                 pt_br: 'Comando Atual',
                 sp: 'Comando Actual',
+                sp_la: 'Comando actual',
                 tr: 'Geçerli Komut',
                 th: 'คำสั่งปัจจุบัน',
                 fr: 'Commande',
@@ -145,6 +171,7 @@ const translationMap = {
                 de: 'Ausgabe',
                 pt_br: 'Saída',
                 sp: 'Salida',
+                sp_la: 'Salida',
                 tr: 'Çıktı',
                 fr: 'Sortie',
                 it: 'Output',
@@ -161,6 +188,7 @@ const translationMap = {
                 de: 'auto-py-to-exe spezifische Optionen',
                 pt_br: 'Opções Específicas auto-py-to-exe',
                 sp: 'Opciones Específicas auto-py-to-exe',
+                sp_la: 'Opciones Específicas auto-py-to-exe',
                 tr: 'auto-py-to-exe ye Özel Seçenekler',
                 th: 'auto-py-to-exe ตัวเลือกเฉพาะ',
                 fr: 'Options spécifiques',
@@ -178,6 +206,7 @@ const translationMap = {
                 de: 'Ausgabeverzeichnis',
                 pt_br: 'Diretório de Saída',
                 sp: 'Directorio de Salida',
+                sp_la: 'Ubicacion de salida',
                 tr: 'Çıktı Dizini',
                 th: 'Output Directory',
                 fr: 'Repertoire de sortie',
@@ -195,9 +224,10 @@ const translationMap = {
                 de: 'Erhöhen der Rekursionsbegrenzung',
                 pt_br: 'Limite de Recursividade',
                 sp: 'Límite de Recursividad',
+                sp_la: 'Límite de Recursividad',
                 tr: 'Özyineleme Sınırını Artırın',
                 th: 'ขีด จำกัด การเรียกซ้ำ',
-                fr:'Augmenter la limite de récursivité',
+                fr: 'Augmenter la limite de récursivité',
                 it: 'Aumenta limite recursione',
                 id: 'Tingkatkan Batas Pengulangan',
                 cz: 'Zvýšit limit rekurze',
@@ -212,6 +242,7 @@ const translationMap = {
                 de: 'Optionen manuell eingeben',
                 pt_br: 'Opções Manuais',
                 sp: 'Opciones Manuales',
+                sp_la: 'Opciones manuales',
                 tr: 'Seçenekleri Manuel Olarak Sağlayın',
                 th: 'ระบุตัวเลือกด้วยตนเอง',
                 fr: 'Fournir manuellement des options',
@@ -229,6 +260,7 @@ const translationMap = {
                 de: 'Manuelle Argumenteingabe',
                 pt_br: 'Argumentos de Entrada',
                 sp: 'Argumentos de Entrada',
+                sp_la: 'Argumentos de entrada',
                 tr: 'Manuel Argüman Girişi',
                 th: 'ระบุตัวเลือกด้วยตนเอง',
                 fr: 'Saisie manuelle des arguments',
@@ -246,6 +278,7 @@ const translationMap = {
                 de: 'Konfiguration',
                 pt_br: 'Configuração',
                 sp: 'Configuración',
+                sp_la: 'Configuración',
                 tr: 'Yapılandırma',
                 th: 'การกำหนดค่า',
                 fr: 'Paramétrage',
@@ -265,6 +298,7 @@ const translationMap = {
                 de: 'Durchsuchen',
                 pt_br: 'Exibir',
                 sp: 'Mostrar',
+                sp_la: 'Mostrar',
                 tr: 'Araştır',
                 th: 'เลือก',
                 fr: 'Navigateur',
@@ -282,6 +316,7 @@ const translationMap = {
                 de: 'Ein Verzeichnis',
                 pt_br: 'Um Diretório',
                 sp: 'Un directorio',
+                sp_la: 'Directorio unico',
                 tr: 'Tek Dizin',
                 th: 'หนึ่งไดเรกทอรี',
                 fr: 'un répertoire',
@@ -299,6 +334,7 @@ const translationMap = {
                 de: 'Eine Datei',
                 pt_br: 'Um Arquivo',
                 sp: 'Un Archivo',
+                sp_la: 'Unico archivo',
                 tr: 'Tek Dosya',
                 th: 'ไฟล์เดียว',
                 fr: 'Un fichier',
@@ -316,6 +352,7 @@ const translationMap = {
                 de: 'Befehlszeilenbasiert',
                 pt_br: 'Baseado em Console',
                 sp: 'Consola básica',
+                sp_la: 'Consola básica',
                 tr: 'Konsol Tabanlı',
                 th: 'คอนโซล',
                 fr: 'Présence de la console',
@@ -333,6 +370,7 @@ const translationMap = {
                 de: 'Fensterbasiert (Befehlszeile ausblenden)',
                 pt_br: 'Baseado em Janela (ocultar o console)',
                 sp: 'Consola de Windows (Ocultar consola)',
+                sp_la: 'Ventana (ocultar consola)',
                 tr: 'Pencere Tabanlı (Konsolu gizleyin)',
                 th: 'หน้าต่าง (ซ่อนคอนโซล)',
                 fr: 'Basé sur windows (la console n\'est pas visible)',
@@ -350,6 +388,7 @@ const translationMap = {
                 de: 'Dateien hinzufügen',
                 pt_br: 'Adicionar Arquivos',
                 sp: 'Añadir archivos',
+                sp_la: 'Añadir archivos',
                 tr: 'Dosyalar Ekle',
                 th: 'เพิ่มไฟล์',
                 fr: 'Ajout de fichiers',
@@ -367,6 +406,7 @@ const translationMap = {
                 de: 'Verzeichnis hinzufügen',
                 pt_br: 'Adicionar Pasta',
                 sp: 'Añadir carpeta',
+                sp_la: 'Añadir carpeta',
                 tr: 'Klasör Ekle',
                 th: 'เพิ่มแฟ้มใหม่',
                 fr: 'Ajout de dossiers',
@@ -384,6 +424,7 @@ const translationMap = {
                 de: 'Leerzeichen hinzufügen',
                 pt_br: 'Adicionar em Branco',
                 sp: 'Añadir en blanco',
+                sp_la: 'Añadir en blanco',
                 tr: 'Boş Alan Ekle',
                 th: 'เพิ่มช่องว่าง',
                 fr: 'Ajout de pages',
@@ -401,6 +442,7 @@ const translationMap = {
                 de: 'Konfiguration aus JSON-Datei importieren',
                 pt_br: 'Importar Config de Arquivo JSON',
                 sp: 'Importar Configuración de Archivo JSON',
+                sp_la: 'Importar Configuración de un archivo JSON',
                 tr: 'Yapılandırmayı JSON Dosyasından İçe Aktar',
                 th: 'นำเข้าการตั้งค่า (ไฟล์ JSON)',
                 fr: 'Importation de la configuration d\'un fichier JSON',
@@ -418,6 +460,7 @@ const translationMap = {
                 de: 'Konfiguration in JSON-Datei exportieren',
                 pt_br: 'Exportar Config para Arquivo JSON',
                 sp: 'Exportar Configuración para Archivo JSON',
+                sp_la: 'Exportar Configuración a un archivo JSON',
                 th: 'ส่งออกการตั้งค่า (ไฟล์ JSON)',
                 fr: 'Exportation de la configuration vers un fichier JSON',
                 it: 'Esporta configurazione su un file JSON',
@@ -434,6 +477,7 @@ const translationMap = {
                 de: 'Konvertiere .py in .exe',
                 pt_br: 'Converter .py para .exe',
                 sp: 'Convertir .py a .exe',
+                sp_la: 'Convertir .py a .exe',
                 tr: '.py\'yi .exe\'ye dönüştürün',
                 th: 'เริ่มการแปลงไฟล์',
                 fr: 'Convert. .py vers .exe',
@@ -451,6 +495,7 @@ const translationMap = {
                 de: 'Ausgabeverzeichnis öffnen',
                 pt_br: 'Abrir Pasta de Saída',
                 sp: 'Abrir Carpeta de Destino',
+                sp_la: 'Abrir carpeta de destino',
                 tr: 'Çıktı Klasörünü Aç',
                 th: 'เปิดโฟลเดอร์ผลลัพธ์',
                 fr: 'Ouvrir le dossier de sortie',
@@ -468,6 +513,7 @@ const translationMap = {
                 de: 'Aktivieren',
                 pt_br: 'Habilitar',
                 sp: 'Habilitar',
+                sp_la: 'Habilitar',
                 tr: 'Aktif',
                 th: 'เปิดใช้งาน',
                 fr: 'Autorisé',
@@ -487,6 +533,7 @@ const translationMap = {
                 de: 'Hilfe-Post',
                 pt_br: 'Post Ajuda',
                 sp: 'Ayuda',
+                sp_la: 'Ayuda',
                 tr: 'Yardım',
                 th: 'บทความช่วยเหลือ',
                 fr: 'Message d\'aide',
@@ -506,6 +553,7 @@ const translationMap = {
                 de: 'Pfad zur Datei',
                 pt_br: 'Caminhao para Arquivo',
                 sp: 'Ruta de archivo',
+                sp_la: 'Ruta de archivo',
                 tr: 'Dosya yolu',
                 th: 'เส้นทางไปยังไฟล์',
                 fr: 'Chemin vers le fichier',
@@ -523,6 +571,7 @@ const translationMap = {
                 de: '.ico Datei',
                 pt_br: 'Arquivo .ico',
                 sp: 'Archivo .ico',
+                sp_la: 'Archivo .ico',
                 tr: '.ico Dosyasi',
                 th: '.ico ไฟล์',
                 fr: '.ico fichier',
@@ -540,6 +589,7 @@ const translationMap = {
                 de: 'VERZEICHNIS',
                 pt_br: 'DIRETÓRIO',
                 sp: 'Directorio',
+                sp_la: 'Directorio',
                 tr: 'Dizin',
                 th: 'ไดเรกทอรี',
                 fr: 'REPERTOIRE',
@@ -557,6 +607,7 @@ const translationMap = {
                 de: 'ARGUMENTE',
                 pt_br: 'ARGUMENTOS',
                 sp: 'ARGUMENTOS',
+                sp_la: 'ARGUMENTOS',
                 tr: 'ARGÜMANLAR',
                 th: 'อาร์กิวเมนต์',
                 fr: 'ARGUMENTS',
@@ -575,6 +626,7 @@ const translationMap = {
                 ru: 'Папка, в которую переместиться итоговое приложение. Будет создано при необходимости.',
                 pt_br: 'O diretório para colocar a saída. Será criado se não existir',
                 sp: 'El directorio para colocar el archivo de salida. Será creado si no existe',
+                sp_la: 'El directorio para colocar el archivo de salida. Será creado si no existe',
                 tr: 'Çıktının yerleştirileceği dizin. Mevcut değilse oluşturulacaktır.',
                 th: 'Directory สำหรับ Output ไฟล์ จะถูกสร้างขึ้น ถ้า Directory นั้นไม่มี',
                 fr: 'Le répertoire sera créé s\'il n\'existe pas.',
@@ -591,6 +643,7 @@ const translationMap = {
                 ru: 'Если включено установит лимит рекурсии равный 5000 с помощью sys.setrecursionlimit(5000).',
                 pt_br: 'Ativar isso definirá o limite de recursão para 5000 usando sys.setrecursionlimit(5000)',
                 sp: 'Al activar esto se definirá el límite de recursión a 5000 usando sys.setrecursionlimit(5000)',
+                sp_la: 'Al activar esto se definirá el límite de recursión a 5000 usando sys.setrecursionlimit(5000)',
                 tr: 'Bunun etkinleştirilmesi, sys.setrecursionlimit(5000) kullanılarak yineleme sınırını 5000\'e ayarlayacaktır.',
                 th: 'การเปิดใช้งานนี้จะตั้งค่าขีดจำกัดการเรียกซ้ำเป็น 5000 โดยใช้ sys.setrecursionlimit(5000)',
                 fr: 'L\'activation de cette option définira la limite de récursivité à 5000 en utilisant sys.setrecursionlimit(5000).',
@@ -607,6 +660,7 @@ const translationMap = {
                 ru: 'Вставит текст в итоговую команду',
                 pt_br: 'Injete texto bruto no comando gerado.',
                 sp: 'Inserte texto bruto en el comando generado',
+                sp_la: 'Inserte texto bruto en el comando generado',
                 tr: 'Oluşturulan komuta ham metin ekleyin.',
                 th: 'ใส่ raw text ลงในคำสั่งที่สร้างขึ้น',
                 fr: 'Injectez du texte brut dans la commande générée.',
@@ -622,10 +676,10 @@ const translationMap = {
                 en: 'Be careful when using additional files with onefile mode;\n' +
                     '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">read this</a>\n' +
                     'and update your code to work with PyInstaller.',
-                zh: '使用单文件模式的附加文件时要小心;\n'+
+                zh: '使用单文件模式的附加文件时要小心;\n' +
                     '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">read this</a>\n' +
                     '并更新您的代码以使用PyInstaller。',
-                zh_tw: '使用單檔案模式的附加檔案時要小心;\n'+
+                zh_tw: '使用單檔案模式的附加檔案時要小心;\n' +
                     '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">read this</a>\n' +
                     '並更新您的代碼以使用 PyInstaller。',
                 ru: 'Будьте внимательны при использовании дополнительных файлов в режиме одного файла;\n' +
@@ -637,6 +691,9 @@ const translationMap = {
                 sp: 'Tenga cuidado al utilizar archivos adicionales con el modo de un solo archivo;\n' +
                     '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">read this</a>\n' +
                     'and update your code to work with PyInstaller.',
+                sp_la: 'Tenga cuidado al utilizar archivos adicionales con el modo de un solo archivo;\n' +
+                    '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">read this</a>\n' +
+                    'y actualiza tu codigo para funcionar con PyInstaller.',
                 tr: 'Tek dosya modunda ek dosyalar kullanırken dikkatli olun;\n' +
                     '<a href="https://stackoverflow.com/a/13790741/" style="text-decoration: none;">read this</a>\n' +
                     've kodunuzu PyInstaller ile çalışacak şekilde güncelleyin.',
@@ -669,6 +726,7 @@ const translationMap = {
                 ru: 'Если вы хотите расположить файлы в главной директории, вставьте точку (.) в начале пути.',
                 pt_br: 'Se você quiser colocar arquivos no diretório raiz, coloque um ponto (.) no destino.',
                 sp: 'Si quiere poner los archivos en el directorio raíz, ponga un punto (.) en el destino.',
+                sp_la: 'Si quiere poner los archivos en el directorio raíz, ponga un punto (.) en el destino.',
                 tr: 'Dosyaları kök dizine koymak istiyorsanız, hedefe nokta (.) koyun.',
                 th: 'หากคุณต้องการใส่ไฟล์ในไดเร็กทอรีราก ให้ใส่จุด (.) ที่ปลายทาง',
                 fr: 'Si vous souhaitez placer des fichiers dans le répertoire racine, mettez un point (.) dans la destination.',
@@ -709,6 +767,10 @@ const translationMap = {
                     '    este post contiene posibles problemas comunes\n' +
                     '</a>\n' +
                     'y posibles soluciones.',
+                sp_la: 'Algo fue mal con tu archivo .exe? Lea \n' +
+                    '<a href="https://nitratine.net/blog/post/issues-when-using-auto-py-to-exe/?utm_source=auto_py_to_exe&utm_medium=application_link&utm_campaign=auto_py_to_exe_help&utm_content=bottom" target="_blank">\n' +
+                    '    este post contiene posibles soluciones a problemas comunes' +
+                    '</a>.\n',
                 tr: 'exe\'nizde bir sorun mu var? Oku\n' +
                     '<a href="https://nitratine.net/blog/post/issues-while-using-auto-py-to-exe/?utm_source=auto_py_to_exe&utm_medium=application_link&utm_campaign=auto_py_to_exe_help&utm_content=bottom" target="_blank">\ n' +
                     ' yaygın sorunların nasıl çözüleceğiyle ilgili bu gönderiye bakin\n' +
@@ -764,6 +826,7 @@ const translationMap = {
                 de: 'Allgemeine Optionen',
                 pt_br: 'Opções Gerais',
                 sp: 'Opciones generales',
+                sp_la: 'Opciones generales',
                 tr: 'Genel Seçenekler',
                 th: 'ตัวเลือกทั่วไป',
                 fr: 'Options Générales',
@@ -781,6 +844,7 @@ const translationMap = {
                 de: 'Was zusammenfassen, wo suchen',
                 pt_br: 'O que agrupar, onde pesquisar',
                 sp: 'Qué agrupar, dónde buscar',
+                sp_la: 'Qué agrupar, dónde buscar',
                 tr: 'Ne paketlenir, nerede aranır',
                 th: 'What to bundle, ค้นหาที่ไหน',
                 fr: 'Quoi regrouper, où chercher',
@@ -798,6 +862,7 @@ const translationMap = {
                 de: 'Wie generieren...?',
                 pt_br: 'Como gerar',
                 sp: 'Como generar',
+                sp_la: 'Como generar',
                 tr: 'Nasıl oluşturulur',
                 th: 'วิธีการ generate',
                 fr: 'Comment générer',
@@ -814,6 +879,7 @@ const translationMap = {
                 de: 'Windows und Mac Os X spezifische Optionen',
                 pt_br: 'Opções específicas Windows e Mac Os X',
                 sp: 'Opciones específicas Windows y Mac Os X',
+                sp_la: 'Opciones específicas de Windows y de Mac Os X',
                 tr: 'Windows ve Mac Os X\'e Özel Seçenekler',
                 th: 'ตัวเลือกเฉพาะของ Windows และ Mac Os X',
                 fr: 'Windows et Mac Os X options specifiques',
@@ -831,6 +897,7 @@ const translationMap = {
                 de: 'Windows spezifische Optionen',
                 pt_br: 'Opções específicas Windows',
                 sp: 'Opciones específicas Windows',
+                sp_la: 'Opciones específicas de Windows',
                 tr: 'Windows\'a özel seçenekler',
                 th: 'ตัวเลือกเฉพาะของ Windows',
                 fr: 'Options spécifiques à Windows',
@@ -848,6 +915,7 @@ const translationMap = {
                 de: 'Windows Side-by-side Suchoptionen (Erweitert)',
                 pt_br: 'Opções de pesquisa dSide-by-side Assembly do Windows (avançado)',
                 sp: 'Opciones de búsqueda de ensamblaje en paralelo para Windows (avanzadas)',
+                sp_la: 'Opciones de búsqueda de ensamblaje en paralelo para Windows (avanzadas)',
                 tr: 'Windows Yan Yana Montaj arama seçenekleri (gelişmiş)',
                 th: 'ตัวเลือกการค้นหา Assembly ของ Windows Side-by-side (ขั้นสูง)',
                 fr: 'Options de recherche Windows Side-by-side Assembly (avancées)',
@@ -865,6 +933,7 @@ const translationMap = {
                 de: 'Mac OS X spezifische Optionen',
                 pt_br: 'Opções específicas Mac OS X',
                 sp: 'Opciones específicas Mac OS X',
+                sp_la: 'Opciones específicas de Mac OS X',
                 tr: 'Mac OS X\'e özel seçenekler',
                 th: 'ตัวเลือกเฉพาะของ Mac OS X',
                 fr: 'Options spécifiques pour Mac Os X',
@@ -882,6 +951,7 @@ const translationMap = {
                 de: 'Selten genuzte Spezialoptionen',
                 pt_br: 'Opções especiais raramente usadas',
                 sp: 'Opciones especiales raramente usadas',
+                sp_la: 'Opciones especiales raramente usadas',
                 tr: 'Nadiren kullanılan özel seçenekler',
                 th: 'ตัวเลือกพิเศษ (ไม่ค่อยได้ใช้)',
                 fr: 'Options spéciales rarement utilisées',
@@ -899,6 +969,7 @@ const translationMap = {
                 de: 'Andere',
                 pt_br: 'Outros',
                 sp: 'Otros',
+                sp_la: 'Otros',
                 tr: 'Diğer',
                 th: 'อื่นๆ',
                 fr: 'Autres',
@@ -919,6 +990,7 @@ const translationMap = {
                 de: 'Datei suchen',
                 pt_br: 'Procurar arquivo',
                 sp: 'Buscar archivo',
+                sp_la: 'Buscar archivo',
                 tr: 'Dosyaya Gözat',
                 th: 'เรียกดูไฟล์',
                 fr: 'Rechercher un fichier',
@@ -936,6 +1008,7 @@ const translationMap = {
                 de: 'Verzeichnis suchen',
                 pt_br: 'Procurar Pasta',
                 sp: 'Buscar carpeta',
+                sp_la: 'Buscar carpeta',
                 tr: 'Klasöre Gözat',
                 th: 'เรียกดูโฟลเดอร์',
                 fr: 'Rechercher un dossier',
@@ -953,6 +1026,7 @@ const translationMap = {
                 de: 'Aktivieren',
                 pt_br: 'Habilitar',
                 sp: 'Habilitar',
+                sp_la: 'Habilitar',
                 tr: 'Aktif',
                 th: 'เปิดใช้งาน',
                 fr: 'Activer',
@@ -970,6 +1044,7 @@ const translationMap = {
                 de: 'Deaktivieren',
                 pt_br: 'Desabilitar',
                 sp: 'Deshabilitar',
+                sp_la: 'Deshabilitar',
                 tr: 'Devre Dışı',
                 th: 'ปิดการใช้งาน',
                 fr: 'Désactiver',
@@ -987,6 +1062,7 @@ const translationMap = {
                 de: 'Konvertierung...',
                 pt_br: 'Convertendo...',
                 sp: 'Convirtiendo...',
+                sp_la: 'Generando...',
                 tr: 'Dönüştürülüyor...',
                 th: 'กำลังแปลง...',
                 fr: 'Conversion...',
@@ -1004,6 +1080,7 @@ const translationMap = {
                 de: 'Ausgabe löschen',
                 pt_br: 'Limpar Saída',
                 sp: 'Limpiar Salida',
+                sp_la: 'Limpiar Salida',
                 tr: 'Çıktıyı Temizle',
                 th: 'Clear Output',
                 fr: 'Effacer la sortie',
@@ -1023,6 +1100,7 @@ const translationMap = {
                 de: 'Aktuelle Konfiguration überschreiben?',
                 pt_br: 'Substituir a configuração atual?',
                 sp: 'Sustituir configuración actual?',
+                sp_la: '¿Sustituir configuración actual?',
                 tr: 'Geçerli yapılandırma geçersiz kılınsın mı?',
                 th: 'เขียนทับการกำหนดค่าปัจจุบัน?',
                 fr: 'Remplacer la configuration actuelle ?',
@@ -1040,6 +1118,7 @@ const translationMap = {
                 de: 'Alle zuvor eingegebenen Werte werden gelöscht.',
                 pt_br: 'Todos os valores inseridos anteriormente serão apagados.',
                 sp: 'Todos los valores insertados previamente serán borrados',
+                sp_la: 'Todos los valores insertados previamente serán borrados',
                 tr: 'Önceden girilen tüm değerler silinecek.',
                 th: 'ค่าที่ใส่ไว้ก่อนหน้านี้จะถูกลบ',
                 fr: 'Toutes les valeurs précédemment insérées seront effacées.',
@@ -1057,6 +1136,7 @@ const translationMap = {
                 de: 'Bestätigen',
                 pt_br: 'Confirma',
                 sp: 'Confirmar',
+                sp_la: 'Confirmar',
                 tr: 'Onayla',
                 th: 'ยืนยัน',
                 fr: 'confimer',
@@ -1074,6 +1154,7 @@ const translationMap = {
                 de: 'Abbrechen',
                 pt_br: 'Cancela',
                 sp: 'Cancelar',
+                sp_la: 'Cancelar',
                 tr: 'İptal',
                 th: 'ยกเลิก',
                 fr: 'Annuler',
@@ -1096,6 +1177,7 @@ const translationMap = {
                 de: 'Keinen Pfad zum Skript angegeben.\nBitte den Pfad zum Skript oben in der Seite eingeben.',
                 pt_br: 'Você não forneceu o local dos seus scripts.\nPor favor, insira-o na parte superior da página.',
                 sp: 'No ha facilitado la ubicación de sus guiones. \nPor favor, introdúzcala en la parte superior de la página.',
+                sp_la: 'No ha facilitado la ubicación de sus guiones. \nPor favor, introdúzcala en la parte superior de la página.',
                 tr: 'Komut dosyanızın konumunu belirtmediniz.\nLütfen bunu sayfanın en üstüne girin.',
                 th: 'คุณยังไม่ได้ระบุตำแหน่งสคริปต์ของคุณ\nโปรดป้อนข้อมูลนี้ที่ด้านบนของหน้า',
                 fr: 'Vous n\'avez pas fourni l\'emplacement de vos scripts.\nVeuillez le saisir en haut de la page.',
@@ -1113,6 +1195,7 @@ const translationMap = {
                 de: 'Diese Aktion wird vorige Ausgaben im Ausgabeverzeichnis überschreiben.\nWeitermachen?',
                 pt_br: 'Esta ação substituirá uma saída anterior na pasta de saída.\nContinuar?',
                 sp: 'Esta acción sobrescribirá una salida anterior en la carpeta de salida.\n¿Continuar?',
+                sp_la: 'Esta acción sobrescribirá una salida anterior en la carpeta de salida.\n¿Desea continuar?',
                 tr: 'Bu eylem, çıktı klasöründeki önceki bir çıktının üzerine yazacak.\nDevam edilsin mi?',
                 th: 'การดำเนินการนี้จะเขียนทับเอาต์พุตก่อนหน้าในโฟลเดอร์เอาต์พุต\nทำต่อหรือไม่',
                 fr: 'Cette action écrasera une sortie précédente dans le dossier de sortie.\nContinuer ?',
@@ -1182,8 +1265,8 @@ const translate = (language) => {
 
 const _getLanguage = () => {
     const language = navigator.languages && navigator.languages[0] || // Chrome / Firefox
-          navigator.language || // All browsers
-          navigator.userLanguage; // IE <= 10
+        navigator.language || // All browsers
+        navigator.userLanguage; // IE <= 10
 
     let shortLang = language;
     if (shortLang.indexOf('-') !== -1) {
@@ -1269,6 +1352,10 @@ const supportedLanguages = [
         name: 'Spanish (Español)',
         code: 'sp',
     },
+    {
+        name: 'Spanish Latam (Español Latam)',
+        code: 'sp_la',
+    },
     {
         name: 'Thai (ภาษาไทย)',
         code: 'th',
